@@ -7,7 +7,7 @@ duoComparisonDiamondPlot <- function(dat, items = NULL,
                                      decreasing=NULL,
                                      conf.level=c(.95, .95),
                                      showData = TRUE, dataAlpha = .1, dataSize=3,
-                                     comparisonColors = viridis::viridis(length(unique(dat[, compareBy]))),
+                                     comparisonColors = viridisPalette(length(unique(dat[, compareBy]))),
                                      associationsColor = 'grey',
                                      alpha = .33,
                                      jitterWidth = .5,
