@@ -86,9 +86,7 @@ meanSDtoDiamondPlot <- function(dat = NULL,
                                 outputFile = NULL,
                                 outputWidth = 10,
                                 outputHeight = 10,
-                                ggsaveParams = list(units='cm',
-                                                    dpi=300,
-                                                    type="cairo"),
+                                ggsaveParams = ufs::opts$get("ggsaveParams"),
                                 ...) {
 
   varNamesToUse <- c(means, sds, ns);
